*Thanks to Fysi#1610 for putting these together*

Each number corresponds to the location of the door in the "doors" array.

# Frigate Orpheon
![](Frigate_Annotated.png)

# Tallon Overworld
![](Tallon_Annotated.png)

# Chozo Ruins
![](Chozo_Annotated.png)

# Magmoor Caverns
![](Magmoor_Annotated.png)

# Phendrana Drifts
![](Phendrana_Annotated.png)

# Phazon Mines
![](Mines_Annotated.png)

# Impact Crater
![](Crater_Annotated.png)
